@@ -469,7 +469,7 @@ class RunnerConfig(object):
         new_args.extend([
             '--die-with-parent',
             '--unshare-pid',
-            '--dev', '/dev',
+            '--dev-bind', '/dev', 'dev',
             '--proc', '/proc',
             '--dir', '/tmp',
             '--ro-bind', '/bin', '/bin',
