@@ -428,7 +428,7 @@ def test_process_isolation_defaults():
         'bwrap',
         '--die-with-parent',
         '--unshare-pid',
-        '--dev', '/dev',
+        '--dev-bind', '/dev', 'dev',
         '--proc', '/proc',
         '--dir', '/tmp',
         '--ro-bind', '/bin', '/bin',
@@ -466,7 +466,7 @@ def test_process_isolation_and_directory_isolation(mock_makedirs, mock_copytree,
         'bwrap',
         '--die-with-parent',
         '--unshare-pid',
-        '--dev', '/dev',
+        '--dev-bind', '/dev', 'dev',
         '--proc', '/proc',
         '--dir', '/tmp',
         '--ro-bind', '/bin', '/bin',
@@ -500,7 +500,7 @@ def test_process_isolation_settings():
         'not_bwrap',
         '--die-with-parent',
         '--unshare-pid',
-        '--dev', '/dev',
+        '--dev-bind', '/dev', 'dev',
         '--proc', '/proc',
         '--dir', '/tmp',
         '--ro-bind', '/bin', '/bin',
